@@ -13,7 +13,7 @@ depends() {
 
 # called by dracut
 install() {
-    dracut_install evmctl keyctl
+    inst_multiple evmctl keyctl
     inst_hook pre-pivot 61 "$moddir/evm-enable.sh"
     inst_hook pre-pivot 61 "$moddir/ima-keys-load.sh"
     inst_hook pre-pivot 62 "$moddir/ima-policy-load.sh"
